==> kdev-php-22.04.1-x86_64-1.txz: usr/lib64/cmake/KDevPHP/KDevPHPTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "kdevphpparser" for configuration "Release"
set_property(TARGET kdevphpparser APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kdevphpparser PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Language;KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libkdevphpparser.so"
  IMPORTED_SONAME_RELEASE "libkdevphpparser.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS kdevphpparser )
list(APPEND _IMPORT_CHECK_FILES_FOR_kdevphpparser "${_IMPORT_PREFIX}/lib64/libkdevphpparser.so" )

# Import target "kdevphpduchain" for configuration "Release"
set_property(TARGET kdevphpduchain APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kdevphpduchain PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Interfaces;KDev::Language;KDev::Shell;KDev::Project;kdevphpparser"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libkdevphpduchain.so"
  IMPORTED_SONAME_RELEASE "libkdevphpduchain.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS kdevphpduchain )
list(APPEND _IMPORT_CHECK_FILES_FOR_kdevphpduchain "${_IMPORT_PREFIX}/lib64/libkdevphpduchain.so" )

# Import target "kdevphpcompletion" for configuration "Release"
set_property(TARGET kdevphpcompletion APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kdevphpcompletion PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Language;KDev::Interfaces;KDev::Project;kdevphpduchain;kdevphpparser"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libkdevphpcompletion.so"
  IMPORTED_SONAME_RELEASE "libkdevphpcompletion.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS kdevphpcompletion )
list(APPEND _IMPORT_CHECK_FILES_FOR_kdevphpcompletion "${_IMPORT_PREFIX}/lib64/libkdevphpcompletion.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kdev-php-23.08.3-x86_64-1.txz: usr/lib64/cmake/KDevPHP/KDevPHPTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "kdevphpparser" for configuration "Release"
set_property(TARGET kdevphpparser APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kdevphpparser PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Language;KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libkdevphpparser.so"
  IMPORTED_SONAME_RELEASE "libkdevphpparser.so"
  )

list(APPEND _cmake_import_check_targets kdevphpparser )
list(APPEND _cmake_import_check_files_for_kdevphpparser "${_IMPORT_PREFIX}/lib64/libkdevphpparser.so" )

# Import target "kdevphpduchain" for configuration "Release"
set_property(TARGET kdevphpduchain APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kdevphpduchain PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Interfaces;KDev::Language;KDev::Shell;KDev::Project;kdevphpparser"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libkdevphpduchain.so"
  IMPORTED_SONAME_RELEASE "libkdevphpduchain.so"
  )

list(APPEND _cmake_import_check_targets kdevphpduchain )
list(APPEND _cmake_import_check_files_for_kdevphpduchain "${_IMPORT_PREFIX}/lib64/libkdevphpduchain.so" )

# Import target "kdevphpcompletion" for configuration "Release"
set_property(TARGET kdevphpcompletion APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kdevphpcompletion PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Language;KDev::Interfaces;KDev::Project;kdevphpduchain;kdevphpparser"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libkdevphpcompletion.so"
  IMPORTED_SONAME_RELEASE "libkdevphpcompletion.so"
  )

list(APPEND _cmake_import_check_targets kdevphpcompletion )
list(APPEND _cmake_import_check_files_for_kdevphpcompletion "${_IMPORT_PREFIX}/lib64/libkdevphpcompletion.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
